
.. _developer-manual:

Developer Manual
================

.. toctree::
   :maxdepth: 2

   contributing.rst
   release.rst
   repomap.rst
   architecture.rst
   dispatching.rst
   generators.rst
   numba-runtime.rst
   rewrites.rst
   live_variable_analysis.rst
   listings.rst
   stencil.rst
   custom_pipeline.rst
   inlining.rst
   environment.rst
   hashing.rst
   caching.rst
   threading_implementation.rst
   literal.rst
   llvm_timings.rst
   debugging.rst
   event_api.rst
   target_extension.rst
   mission.rst
